
Tendril Status Conventions
==========================

.. include:: ../README.rst
    :start-after: inclusion-marker-do-not-remove

.. raw:: latex

       \vspace*{\fill}

.. tabularcolumns:: >{\raggedleft\arraybackslash}\Y{0.1} >{\raggedright\arraybackslash}\Y{0.5}

.. list-table::
    :widths: 8 40
    :header-rows: 0


    * -
        .. figure:: _static/logo_packed.png
                :align: right
      -
        .. raw:: latex

            \vspace{-1.5em}

        ``tendril-conventions-status`` is part of the tendril framework for the management of engineering information

.. raw:: latex

      \clearpage


Documentation
-------------

.. toctree::
   :maxdepth: 3

   installation
   usage/standalone
   usage/tendril
   api/index


.. only:: html

   Indices and tables
   ------------------

   * :ref:`genindex`
   * :ref:`modindex`
   * :ref:`search`
